# HG changeset patch
# User Jim Unroe <rock.unroe@gmail.com>
# Date 1365896788 14400
# Node ID 57d7ee79f868fe65d7f81ef5220b1a6413b8127e
# Parent  35bd3e0c31b761d54c438234a0fe53e2a5b84f2e
add uv5b settings

diff -r 35bd3e0c31b7 -r 57d7ee79f868 chirp/uvb5.py
--- a/chirp/uvb5.py	Wed Apr 10 19:17:38 2013 -0700
+++ b/chirp/uvb5.py	Sat Apr 13 19:46:28 2013 -0400
@@ -15,6 +15,9 @@
 
 import struct
 from chirp import chirp_common, directory, bitwise, memmap, errors, util
+from chirp.settings import RadioSetting, RadioSettingGroup, \
+                RadioSettingValueBoolean, RadioSettingValueList, \
+                RadioSettingValueInteger, RadioSettingValueString
 
 mem_format = """
 struct memory {
@@ -48,6 +51,33 @@
 struct {
   u8 name[5];
 } names[128];
+
+#seekto 0x0D30;
+struct {
+  u8 squelch;
+  u8 freqmode_ab:1,
+     save_funct:1,
+     backlight:1,
+     beep_tone:1,
+     roger:1,
+     tdr:1,
+     scantype:2;
+  u8 voice:1,
+     workmode_b:1,
+     workmode_a:1,
+     workmode_fm:1,
+     voice_prompt:1,
+     fm:1,
+     pttid_eot:1,
+     pttid_bot:1;
+  u8 timeout;
+  u8 mdf_b:2,
+     mdf_a:2,
+     unknown_1:2,
+     txtdr:2;
+  u8 sidetone;
+  u8 vox;
+} settings;
 """
 
 def do_ident(radio):
@@ -127,6 +157,7 @@
 
     def get_features(self):
         rf = chirp_common.RadioFeatures()
+        rf.has_settings = True
         rf.valid_tmodes = ["", "Tone", "TSQL", "DTCS", "Cross"]
         rf.valid_duplexes = DUPLEX
         rf.valid_skips = ["", "S"]
@@ -267,6 +298,29 @@
                     _nam[i] = CHARSET.index(mem.name[i])
                 except IndexError:
                     _nam[i] = 0xFF
+                    
+    def get_settings(self):
+        other = RadioSettingGroup("optional", "Optional Features")
+        top = RadioSettingGroup("top", "All Settings", other)
+
+        options = ["Time", "Carrier", "Search"]
+        rs = RadioSetting("scantype", "Scan Type",
+                          RadioSettingValueList(options,
+                                        options[self._memobj.settings.scantype]))
+        top.append(rs)
+        rs = RadioSetting("timeout", "Time Out Timer[min]",
+                          RadioSettingValueInteger(0, 7, self._memobj.settings.timeout))
+        top.append(rs)
+
+        rs = RadioSetting("squelch", "Squelch Level",
+                          RadioSettingValueInteger(0, 9, self._memobj.settings.squelch))
+        top.append(rs)
+        rs = RadioSetting("vox", "VOX Level",
+                          RadioSettingValueInteger(0, 9, self._memobj.settings.vox))
+        other.append(rs)
+
+        return top
+
 
     @classmethod
     def match_model(cls, filedata, filename):
